package org.dromara.ems.info.service;

import org.dromara.ems.info.domain.FaultHandlingRecord;

import java.util.List;

/**
 * 故障处置记录Service接口
 * 
 * @author Yinq
 * @date 2025-06-05
 */
public interface IFaultHandlingRecordService 
{
    /**
     * 查询故障处置记录
     * 
     * @param id 故障处置记录主键
     * @return 故障处置记录
     */
    public FaultHandlingRecord selectFaultHandlingRecordById(Long id);

    /**
     * 查询故障处置记录列表
     * 
     * @param faultHandlingRecord 故障处置记录
     * @return 故障处置记录集合
     */
    public List<FaultHandlingRecord> selectFaultHandlingRecordList(FaultHandlingRecord faultHandlingRecord);

    /**
     * 新增故障处置记录
     * 
     * @param faultHandlingRecord 故障处置记录
     * @return 结果
     */
    public int insertFaultHandlingRecord(FaultHandlingRecord faultHandlingRecord);

    /**
     * 修改故障处置记录
     * 
     * @param faultHandlingRecord 故障处置记录
     * @return 结果
     */
    public int updateFaultHandlingRecord(FaultHandlingRecord faultHandlingRecord);

    /**
     * 批量删除故障处置记录
     * 
     * @param ids 需要删除的故障处置记录主键集合
     * @return 结果
     */
    public int deleteFaultHandlingRecordByIds(Long[] ids);

    /**
     * 删除故障处置记录信息
     * 
     * @param id 故障处置记录主键
     * @return 结果
     */
    public int deleteFaultHandlingRecordById(Long id);

    /**
     * 导入故障处置记录数据
     *
     * @param recordList 记录数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importFaultHandlingRecord(List<FaultHandlingRecord> recordList, Boolean isUpdateSupport, String operName);
}
